import{e as r}from"./index-DIdmExqc.js";import{Z as n}from"./reka-ui-20at8m45.js";import{d as s,G as l,u as a,D as i,b as p}from"./lucide-BnLGGzuz.js";import{l as c}from"./vueuse-BD5u29vr.js";const v=s({__name:"Separator",props:{orientation:{default:"horizontal"},decorative:{type:Boolean,default:!0},asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array],default:void 0}},setup(o){const t=o,e=c(t,"class");return(d,u)=>(p(),l(a(n),i({"data-slot":"separator"},a(e),{class:a(r)("bg-border shrink-0 data-[orientation=horizontal]:h-px data-[orientation=horizontal]:w-full data-[orientation=vertical]:h-full data-[orientation=vertical]:w-px",t.class)}),null,16,["class"]))}});export{v as _};
